@@ -1,32 +1,36 @@
 import json
+import re
 import shutil
 from pathlib import Path
-import re
 
 # Dictionary responsible for making the symbolic links at the end of the script's run.
 symlink_dict = {}
-am_i_inside_go = "go.d.plugin" in str(Path.cwd())
 
 
 def cleanup():
     """
     clean directories that are either data collection or exporting integrations
     """
-    if am_i_inside_go:
-        for element in Path("modules").glob('**/*/'):
-            if "integrations" in str(element):
-                shutil.rmtree(element)
-    else:
-        for element in Path("collectors").glob('**/*/'):
-            if "integrations" in str(element):
-                shutil.rmtree(element)
+    for element in Path("src/go/plugin/go.d/modules").glob('**/*/'):
+        if "integrations" in str(element):
+            shutil.rmtree(element)
+    for element in Path("src/collectors").glob('**/*/'):
+        # print(element)
+        if "integrations" in str(element):
+            shutil.rmtree(element)
 
-        for element in Path("exporting").glob('**/*/'):
-            if "integrations" in str(element):
-                shutil.rmtree(element)
-        for element in Path("integrations/cloud-notifications").glob('**/*/'):
-            if "integrations" in str(element) and not "metadata.yaml" in str(element):
-                shutil.rmtree(element)
+    for element in Path("src/exporting").glob('**/*/'):
+        if "integrations" in str(element):
+            shutil.rmtree(element)
+    for element in Path("integrations/cloud-notifications").glob('**/*/'):
+        if "integrations" in str(element) and not "metadata.yaml" in str(element):
+            shutil.rmtree(element)
+    for element in Path("integrations/logs").glob('**/*/'):
+        if "integrations" in str(element) and "metadata.yaml" not in str(element):
+            shutil.rmtree(element)
+    for element in Path("integrations/cloud-authentication").glob('**/*/'):
+        if "integrations" in str(element) and not "metadata.yaml" in str(element):
+            shutil.rmtree(element)
 
 
 def generate_category_from_name(category_fragment, category_array):
@@ -46,7 +50,7 @@ def generate_category_from_name(category_fragment, category_array):
                 try:
                     # print("equals")
                     # print(fragment, category_fragment[i+1])
-                    dummy_id = dummy_id + "." + category_fragment[i+1]
+                    dummy_id = dummy_id + "." + category_fragment[i + 1]
                     # print(dummy_id)
                 except IndexError:
                     return category_name.split("/", 1)[1]
@@ -61,8 +65,10 @@ def clean_and_write(md, path):
     Then it writes the buffer on the file provided.
     """
     # clean first, replace
-    md = md.replace("{% details summary=\"", "<details><summary>").replace(
-        "\" %}", "</summary>\n").replace("{% /details %}", "</details>\n")
+    md = md.replace("{% details summary=\"", "<details><summary>")
+    md = md.replace("{% details open=true summary=\"", "<details open><summary>")
+    md = md.replace("\" %}", "</summary>\n")
+    md = md.replace("{% /details %}", "</details>\n")
 
     path.write_text(md)
 
@@ -73,16 +79,23 @@ def add_custom_edit_url(markdown_string, meta_yaml_link, sidebar_label_string, m
     """
 
     output = ""
+    path_to_md_file = ""
 
     if mode == 'default':
         path_to_md_file = f'{meta_yaml_link.replace("/metadata.yaml", "")}/integrations/{clean_string(sidebar_label_string)}'
 
-    elif mode == 'cloud-notifications':
+    elif mode == 'cloud-notification':
         path_to_md_file = meta_yaml_link.replace("metadata.yaml", f'integrations/{clean_string(sidebar_label_string)}')
 
-    elif mode == 'agent-notifications':
+    elif mode == 'agent-notification':
         path_to_md_file = meta_yaml_link.replace("metadata.yaml", "README")
 
+    elif mode == 'cloud-authentication':
+        path_to_md_file = meta_yaml_link.replace("metadata.yaml", f'integrations/{clean_string(sidebar_label_string)}')
+
+    elif mode == 'logs':
+        path_to_md_file = meta_yaml_link.replace("metadata.yaml", f'integrations/{clean_string(sidebar_label_string)}')
+
     output = markdown_string.replace(
         "<!--startmeta",
         f'<!--startmeta\ncustom_edit_url: \"{path_to_md_file}.md\"')
@@ -117,23 +130,29 @@ def read_integrations_js(path_to_file):
         print("Exception", e)
 
 
-def create_overview(integration, filename):
+def create_overview(integration, filename, overview_key_name="overview"):
+    # empty overview_key_name to have only image on overview
+    if not overview_key_name:
+        return f"""# {integration['meta']['name']}
 
-    split = re.split(r'(#.*\n)', integration['overview'], 1)
+<img src="https://netdata.cloud/img/{filename}" width="150"/>
+"""
+
+    split = re.split(r'(#.*\n)', integration[overview_key_name], 1)
 
     first_overview_part = split[1]
     rest_overview_part = split[2]
 
-    if len(filename) > 0:
-        return f"""{first_overview_part}
+    if not filename:
+        return f"""{first_overview_part}{rest_overview_part}
+"""
+
+    return f"""{first_overview_part}
 
 <img src="https://netdata.cloud/img/{filename}" width="150"/>
 
 {rest_overview_part}
 """
-    else:
-        return f"""{first_overview_part}{rest_overview_part}
-"""
 
 
 def build_readme_from_integration(integration, mode=''):
@@ -145,7 +164,8 @@ def build_readme_from_integration(integration, mode=''):
             meta_yaml = integration['edit_link'].replace("blob", "edit")
             sidebar_label = integration['meta']['monitored_instance']['name']
             learn_rel_path = generate_category_from_name(
-                integration['meta']['monitored_instance']['categories'][0].split("."), categories)
+                integration['meta']['monitored_instance']['categories'][0].split("."), categories).replace(
+                "Data Collection", "Collecting Metrics")
             most_popular = integration['meta']['most_popular']
 
             # build the markdown string
@@ -197,7 +217,7 @@ endmeta-->
 meta_yaml: "{meta_yaml}"
 sidebar_label: "{sidebar_label}"
 learn_status: "Published"
-learn_rel_path: "Exporting"
+learn_rel_path: "Exporting Metrics"
 message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE EXPORTER'S metadata.yaml FILE"
 endmeta-->
 
@@ -216,7 +236,7 @@ endmeta-->
             print("Exception in exporter md construction", e, integration['id'])
 
     # NOTIFICATIONS
-    elif mode == 'notification':
+    elif mode == 'agent-notification':
         try:
             # initiate the variables for the notification method
             meta_yaml = integration['edit_link'].replace("blob", "edit")
@@ -229,10 +249,103 @@ endmeta-->
 meta_yaml: "{meta_yaml}"
 sidebar_label: "{sidebar_label}"
 learn_status: "Published"
-learn_rel_path: "{learn_rel_path.replace("notifications", "Alerting/Notifications")}"
+learn_rel_path: "{learn_rel_path.replace("notifications", "Alerts & Notifications/Notifications")}"
 message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE NOTIFICATION'S metadata.yaml FILE"
 endmeta-->
 
+{create_overview(integration, integration['meta']['icon_filename'], "overview")}"""
+
+            if integration['setup']:
+                md += f"""
+{integration['setup']}
+"""
+
+            if integration['troubleshooting']:
+                md += f"""
+{integration['troubleshooting']}
+"""
+
+        except Exception as e:
+            print("Exception in notification md construction", e, integration['id'])
+
+    elif mode == 'cloud-notification':
+        try:
+            # initiate the variables for the notification method
+            meta_yaml = integration['edit_link'].replace("blob", "edit")
+            sidebar_label = integration['meta']['name']
+            learn_rel_path = generate_category_from_name(integration['meta']['categories'][0].split("."), categories)
+
+            # build the markdown string
+            md = \
+                f"""<!--startmeta
+meta_yaml: "{meta_yaml}"
+sidebar_label: "{sidebar_label}"
+learn_status: "Published"
+learn_rel_path: "{learn_rel_path.replace("notifications", "Alerts & Notifications/Notifications")}"
+message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE NOTIFICATION'S metadata.yaml FILE"
+endmeta-->
+
+{create_overview(integration, integration['meta']['icon_filename'], "")}"""
+
+            if integration['setup']:
+                md += f"""
+{integration['setup']}
+"""
+
+            if integration['troubleshooting']:
+                md += f"""
+{integration['troubleshooting']}
+"""
+
+        except Exception as e:
+            print("Exception in notification md construction", e, integration['id'])
+
+    elif mode == 'logs':
+        try:
+            # initiate the variables for the logs integration
+            meta_yaml = integration['edit_link'].replace("blob", "edit")
+            sidebar_label = integration['meta']['name']
+            learn_rel_path = generate_category_from_name(integration['meta']['categories'][0].split("."), categories)
+
+            # build the markdown string
+            md = \
+                f"""<!--startmeta
+meta_yaml: "{meta_yaml}"
+sidebar_label: "{sidebar_label}"
+learn_status: "Published"
+learn_rel_path: "{learn_rel_path.replace("logs", "Logs")}"
+message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE LOGS' metadata.yaml FILE"
+endmeta-->
+
+{create_overview(integration, integration['meta']['icon_filename'])}"""
+
+            if integration['setup']:
+                md += f"""
+{integration['setup']}
+"""
+
+        except Exception as e:
+            print("Exception in logs md construction", e, integration['id'])
+
+
+    # AUTHENTICATIONS
+    elif mode == 'authentication':
+        if True:
+            # initiate the variables for the authentication method
+            meta_yaml = integration['edit_link'].replace("blob", "edit")
+            sidebar_label = integration['meta']['name']
+            learn_rel_path = generate_category_from_name(integration['meta']['categories'][0].split("."), categories)
+
+            # build the markdown string
+            md = \
+                f"""<!--startmeta
+meta_yaml: "{meta_yaml}"
+sidebar_label: "{sidebar_label}"
+learn_status: "Published"
+learn_rel_path: "{learn_rel_path.replace("authentication", "Netdata Cloud/Authentication & Authorization/Cloud Authentication & Authorization Integrations")}"
+message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE AUTHENTICATION'S metadata.yaml FILE"
+endmeta-->
+
 {create_overview(integration, integration['meta']['icon_filename'])}"""
 
             if integration['setup']:
@@ -245,8 +358,8 @@ endmeta-->
 {integration['troubleshooting']}
 """
 
-        except Exception as e:
-            print("Exception in notification md construction", e, integration['id'])
+        # except Exception as e:
+        #     print("Exception in authentication md construction", e, integration['id'])
 
     if "community" in integration['meta'].keys():
         community = "<img src=\"https://img.shields.io/badge/maintained%20by-Community-blue\" />"
@@ -301,27 +414,80 @@ def write_to_file(path, md, meta_yaml, sidebar_label, community, mode='default')
                 except KeyError:
                     # We don't need to print something here.
                     pass
-    elif mode == 'notification':
+    elif mode == 'cloud-notification':
 
-        if "cloud-notifications" in path:
-            # for cloud notifications we generate them near their metadata.yaml
-            name = clean_string(integration['meta']['name'])
+        # for cloud notifications we generate them near their metadata.yaml
+        name = clean_string(integration['meta']['name'])
 
-            if not Path(f'{path}/integrations').exists():
-                Path(f'{path}/integrations').mkdir()
+        if not Path(f'{path}/integrations').exists():
+            Path(f'{path}/integrations').mkdir()
 
-            # proper_edit_name = meta_yaml.replace(
-            #     "metadata.yaml", f'integrations/{clean_string(sidebar_label)}.md\"')
+        # proper_edit_name = meta_yaml.replace(
+        #     "metadata.yaml", f'integrations/{clean_string(sidebar_label)}.md\"')
 
-            md = add_custom_edit_url(md, meta_yaml, sidebar_label, mode='cloud-notifications')
+        md = add_custom_edit_url(md, meta_yaml, sidebar_label, mode='cloud-notification')
 
-            finalpath = f'{path}/integrations/{name}.md'
-        else:
-            # add custom_edit_url as the md file, so we can have uniqueness in the ingest script
-            # afterwards the ingest will replace this metadata with meta_yaml
-            md = add_custom_edit_url(md, meta_yaml, sidebar_label, mode='agent-notifications')
+        finalpath = f'{path}/integrations/{name}.md'
 
-            finalpath = f'{path}/README.md'
+        try:
+            clean_and_write(
+                md,
+                Path(finalpath)
+            )
+        except FileNotFoundError as e:
+            print("Exception in writing to file", e)
+    elif mode == 'agent-notification':
+        # add custom_edit_url as the md file, so we can have uniqueness in the ingest script
+        # afterwards the ingest will replace this metadata with meta_yaml
+
+        md = add_custom_edit_url(md, meta_yaml, sidebar_label, mode='agent-notification')
+
+        finalpath = f'{path}/README.md'
+
+        try:
+            clean_and_write(
+                md,
+                Path(finalpath)
+            )
+
+        except FileNotFoundError as e:
+            print("Exception in writing to file", e)
+    elif mode == 'logs':
+
+        # for logs we generate them near their metadata.yaml
+
+        name = clean_string(integration['meta']['name'])
+
+        if not Path(f'{path}/integrations').exists():
+            Path(f'{path}/integrations').mkdir()
+
+        # proper_edit_name = meta_yaml.replace(
+        #     "metadata.yaml", f'integrations/{clean_string(sidebar_label)}.md\"')
+
+        md = add_custom_edit_url(md, meta_yaml, sidebar_label, mode='logs')
+
+        finalpath = f'{path}/integrations/{name}.md'
+
+        try:
+            clean_and_write(
+                md,
+                Path(finalpath)
+            )
+        except FileNotFoundError as e:
+            print("Exception in writing to file", e)
+    elif mode == 'authentication':
+
+        name = clean_string(integration['meta']['name'])
+
+        if not Path(f'{path}/integrations').exists():
+            Path(f'{path}/integrations').mkdir()
+
+        # proper_edit_name = meta_yaml.replace(
+        #     "metadata.yaml", f'integrations/{clean_string(sidebar_label)}.md\"')
+
+        md = add_custom_edit_url(md, meta_yaml, sidebar_label, mode='cloud-authentication')
+
+        finalpath = f'{path}/integrations/{name}.md'
 
         try:
             clean_and_write(
@@ -338,8 +504,13 @@ def make_symlinks(symlink_dict):
     takes a dictionary with directories that have a 1:1 relationship between their README and the integration (only one) inside the "integrations" folder.
     """
     for element in symlink_dict:
-        # Remove the README to prevent it being a normal file
-        Path(f'{element}/README.md').unlink()
+        if not Path(f'{element}/README.md').exists():
+            Path(f'{element}/README.md').touch()
+        try:
+            # Remove the README to prevent it being a normal file
+            Path(f'{element}/README.md').unlink()
+        except FileNotFoundError:
+            continue
         # and then make a symlink to the actual markdown
         Path(f'{element}/README.md').symlink_to(symlink_dict[element])
 
@@ -356,7 +527,6 @@ cleanup()
 
 categories, integrations = read_integrations_js('integrations/integrations.js')
 
-
 # Iterate through every integration
 for integration in integrations:
 
@@ -367,7 +537,7 @@ for integration in integrations:
         path = build_path(meta_yaml)
         write_to_file(path, md, meta_yaml, sidebar_label, community)
 
-    elif not am_i_inside_go:
+    else:
         # kind of specific if clause, so we can avoid running excessive code in the go repo
         if integration['integration_type'] == "exporter":
 
@@ -376,13 +546,32 @@ for integration in integrations:
             path = build_path(meta_yaml)
             write_to_file(path, md, meta_yaml, sidebar_label, community)
 
-        # kind of specific if clause, so we can avoid running excessive code in the go repo
-        elif integration['integration_type'] == "notification":
+        elif integration['integration_type'] == "agent_notification":
 
             meta_yaml, sidebar_label, learn_rel_path, md, community = build_readme_from_integration(
-                integration, mode='notification')
+                integration, mode='agent-notification')
             path = build_path(meta_yaml)
-            write_to_file(path, md, meta_yaml, sidebar_label, community,  mode='notification')
+            write_to_file(path, md, meta_yaml, sidebar_label, community, mode='agent-notification')
 
+        elif integration['integration_type'] == "cloud_notification":
+
+            meta_yaml, sidebar_label, learn_rel_path, md, community = build_readme_from_integration(
+                integration, mode='cloud-notification')
+            path = build_path(meta_yaml)
+            write_to_file(path, md, meta_yaml, sidebar_label, community, mode='cloud-notification')
+
+        elif integration['integration_type'] == "logs":
+
+            meta_yaml, sidebar_label, learn_rel_path, md, community = build_readme_from_integration(
+                integration, mode='logs')
+            path = build_path(meta_yaml)
+            write_to_file(path, md, meta_yaml, sidebar_label, community, mode='logs')
+
+        elif integration['integration_type'] == "authentication":
+
+            meta_yaml, sidebar_label, learn_rel_path, md, community = build_readme_from_integration(
+                integration, mode='authentication')
+            path = build_path(meta_yaml)
+            write_to_file(path, md, meta_yaml, sidebar_label, community, mode='authentication')
 
 make_symlinks(symlink_dict)
