@@ -411,25 +411,35 @@ detect_package_manager_from_distribution() {
     centos* | clearos* | rocky* | almalinux*)
       package_installer=""
       tree="centos"
-      [[ -n "${yum}" ]] && package_installer="install_yum"
       [[ -n "${dnf}" ]] && package_installer="install_dnf"
+      [[ -n "${yum}" ]] && package_installer="install_yum"
       if [[ "${IGNORE_INSTALLED}" -eq 0 ]] && [[ -z "${package_installer}" ]]; then
         echo >&2 "command 'yum' or 'dnf' is required to install packages on a '${distribution} ${version}' system."
         exit 1
       fi
       ;;
 
-    fedora* | redhat* | red\ hat* | rhel*)
+    redhat* | red\ hat* | rhel*)
       package_installer=
       tree="rhel"
-      [[ -n "${yum}" ]] && package_installer="install_yum"
       [[ -n "${dnf}" ]] && package_installer="install_dnf"
+      [[ -n "${yum}" ]] && package_installer="install_yum"
       if [[ "${IGNORE_INSTALLED}" -eq 0 ]] && [[ -z "${package_installer}" ]]; then
         echo >&2 "command 'yum' or 'dnf' is required to install packages on a '${distribution} ${version}' system."
         exit 1
       fi
       ;;
 
+    fedora*)
+      package_installer="install_dnf"
+      tree="rhel"
+      if [[ "${IGNORE_INSTALLED}" -eq 0 ]] && [[ -z "${package_installer}" ]]; then
+        echo >&2 "command 'yum' or 'dnf' is required to install packages on a '${distribution} ${version}' system."
+        exit 1
+      fi
+      ;;
+
+
     ol*)
       package_installer=
       tree="ol"
@@ -825,6 +835,18 @@ declare -A pkg_libuuid_dev=(
   ['default']=""
 )
 
+declare -A pkg_libcurl_dev=(
+  ['alpine']="curl-dev"
+  ['arch']="curl"
+  ['clearlinux']="devpkg-curl"
+  ['debian']="libcurl4-openssl-dev"
+  ['gentoo']="net-misc/curl"
+  ['ubuntu']="libcurl4-openssl-dev"
+  ['macos']="curl"
+  ['freebsd']="curl"
+  ['default']="libcurl-devel"
+)
+
 declare -A pkg_libmnl_dev=(
   ['alpine']="libmnl-dev"
   ['arch']="libmnl"
@@ -1246,6 +1268,7 @@ packages() {
     suitable_package libyaml-dev
     suitable_package libsystemd-dev
     suitable_package pcre2
+    suitable_package libcurl-dev
   fi
 
   # -------------------------------------------------------------------------
@@ -1531,7 +1554,7 @@ install_yum() {
 
 validate_install_dnf() {
   echo >&2 " > Checking if package '${*}' is installed..."
-  dnf list installed "${*}" > /dev/null 2>&1 || echo "${*}"
+  dnf list --installed "${*}" > /dev/null 2>&1 || echo "${*}"
 }
 
 install_dnf() {
