@@ -53,11 +53,9 @@ INSTALL_PREFIX=""
 NETDATA_AUTO_UPDATES="default"
 NETDATA_CLAIM_URL="https://app.netdata.cloud"
 NETDATA_COMMAND="default"
-NETDATA_DISABLE_CLOUD=0
 NETDATA_INSTALLER_OPTIONS=""
 NETDATA_FORCE_METHOD=""
 NETDATA_OFFLINE_INSTALL_SOURCE=""
-NETDATA_REQUIRE_CLOUD=1
 NETDATA_WARNINGS=""
 RELEASE_CHANNEL="default"
 
@@ -149,8 +147,6 @@ main() {
 
   if [ -n "${NETDATA_CLAIM_TOKEN}" ]; then
     claim
-  elif [ "${NETDATA_DISABLE_CLOUD}" -eq 1 ]; then
-    soft_disable_cloud
   fi
 
   set_auto_updates
@@ -185,8 +181,6 @@ USAGE: kickstart.sh [options]
   --native-only                    Only install if native binary packages are available.
   --static-only                    Only install if a static build is available.
   --build-only                     Only install using a local build.
-  --disable-cloud                  Disable support for Netdata Cloud (default: detect)
-  --require-cloud                  Only install if Netdata Cloud can be enabled. Overrides --disable-cloud.
   --install-prefix <path>          Specify an installation prefix for local builds (default: autodetect based on system type).
   --old-install-prefix <path>      Specify an old local builds installation prefix for uninstall/reinstall (if it's not default).
   --install-version <version>      Specify the version of Netdata to install.
@@ -1183,41 +1177,6 @@ handle_existing_install() {
   esac
 }
 
-soft_disable_cloud() {
-  set_tmpdir
-
-  cloud_prefix="${INSTALL_PREFIX}/var/lib/netdata/cloud.d"
-
-  run_as_root mkdir -p "${cloud_prefix}"
-
-  cat > "${tmpdir}/cloud.conf" << EOF
-[global]
-  enabled = no
-EOF
-
-  run_as_root cp "${tmpdir}/cloud.conf" "${cloud_prefix}/cloud.conf"
-
-  if [ -z "${NETDATA_NO_START}" ]; then
-    case "${SYSTYPE}" in
-      Darwin) run_as_root launchctl kickstart -k com.github.netdata ;;
-      FreeBSD) run_as_root service netdata restart ;;
-      Linux)
-        initpath="$(run_as_root readlink /proc/1/exe)"
-
-        if command -v service > /dev/null 2>&1; then
-          run_as_root service netdata restart
-        elif command -v rc-service > /dev/null 2>&1; then
-          run_as_root rc-service netdata restart
-        elif [ "$(basename "${initpath}" 2> /dev/null)" = "systemd" ]; then
-          run_as_root systemctl restart netdata
-        elif [ -f /etc/init.d/netdata ]; then
-          run_as_root /etc/init.d/netdata restart
-        fi
-        ;;
-    esac
-  fi
-}
-
 confirm_install_prefix() {
   if [ -n "${INSTALL_PREFIX}" ] && [ "${NETDATA_FORCE_METHOD}" != 'build' ]; then
     fatal "The --install-prefix option is only supported together with the --build-only option." F0204
@@ -1246,10 +1205,9 @@ check_claim_opts() {
 # shellcheck disable=SC2235,SC2030
   if [ -z "${NETDATA_CLAIM_TOKEN}" ] && [ -n "${NETDATA_CLAIM_ROOMS}" ]; then
     fatal "Invalid claiming options, claim rooms may only be specified when a token is specified." F0204
-  elif [ -z "${NETDATA_CLAIM_TOKEN}" ] && [ -n "${NETDATA_CLAIM_EXTRA}" ]; then
+  elif [ -z "${NETDATA_CLAIM_TOKEN}" ] && [ -n "${NETDATA_CLAIM_EXTRA}${NETDATA_CLAIM_PROXY}${NETDATA_CLAIM_NORELOAD}${NETDATA_CLAIM_INSECURE}" ]; then
+    # The above condition checks if _any_ claiming options other than the rooms have been set when the token is unset.
     fatal "Invalid claiming options, a claiming token must be specified." F0204
-  elif [ "${NETDATA_DISABLE_CLOUD}" -eq 1 ] && [ -n "${NETDATA_CLAIM_TOKEN}" ]; then
-    fatal "Cloud explicitly disabled, but automatic claiming requested. Either enable Netdata Cloud, or remove the --claim-* options." F0204
   fi
 }
 
@@ -1277,6 +1235,93 @@ is_netdata_running() {
   fi
 }
 
+write_claim_config() {
+  if [ -z "${INSTALL_PREFIX}" ] || [ "${INSTALL_PREFIX}" = "/" ]; then
+    config_path="/etc/netdata"
+    netdatacli="$(command -v netdatacli)"
+  elif [ "${INSTALL_PREFIX}" = "/opt/netdata" ]; then
+    config_path="/opt/netdata/etc/netdata"
+    netdatacli="/opt/netdata/bin/netdatacli"
+  elif [ ! -d "${INSTALL_PREFIX}/netdata" ]; then
+    config_path="${INSTALL_PREFIX}/etc/netdata"
+    netdatacli="${INSTALL_PREFIX}/usr/sbin/netdatacli"
+  else
+    config_path="${INSTALL_PREFIX}/netdata/etc/netdata"
+    netdatacli="${INSTALL_PREFIX}/netdata/usr/sbin/netdatacli"
+  fi
+
+  claim_config="${config_path}/claim.conf"
+
+  if [ "${DRY_RUN}" -eq 1 ]; then
+    progress "Would attempt to write claiming configuration to ${claim_config}"
+    return 0
+  fi
+
+  progress "Writing claiming configuration to ${claim_config}"
+
+  config="[global]"
+  config="${config}\n    url = ${NETDATA_CLAIM_URL}"
+  config="${config}\n    token = ${NETDATA_CLAIM_TOKEN}"
+  if [ -n "${NETDATA_CLAIM_ROOMS}" ]; then
+      config="${config}\n    rooms = ${NETDATA_CLAIM_ROOMS}"
+  fi
+  if [ -n "${NETDATA_CLAIM_PROXY}" ]; then
+      config="${config}\n    proxy = ${NETDATA_CLAIM_PROXY}"
+  fi
+  if [ -n "${NETDATA_CLAIM_INSECURE}" ]; then
+      config="${config}\n    insecure = ${NETDATA_CLAIM_INSECURE}"
+  fi
+
+  run_as_root touch "${claim_config}.tmp" || return 1
+  run_as_root chmod 0640 "${claim_config}.tmp" || return 1
+  run_as_root chown ":${NETDATA_CLAIM_GROUP:-netdata}" "${claim_config}.tmp" || return 1
+  run_as_root sh -c "printf '${config}\\n' > \"${claim_config}.tmp\"" || return 1
+  run_as_root mv -f "${claim_config}.tmp" "${claim_config}" || return 1
+
+  if [ -z "${NETDATA_CLAIM_NORELOAD}" ]; then
+    run_as_root "${netdatacli}" reload-claiming-state || return 1
+  fi
+}
+
+run_claim_script() {
+  if [ -n "${NETDATA_CLAIM_NORELOAD}" ]; then
+    NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -daemon-not-running"
+  fi
+
+  if [ -n "${NETDATA_CLAIM_INSECURE}" ]; then
+    NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -insecure"
+  fi
+
+  if [ -n "${NETDATA_CLAIM_PROXY}" ]; then
+    if [ "${NETDATA_CLAIM_PROXY}" = "none" ]; then
+      NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -noproxy"
+    else
+      NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -proxy=${NETDATA_CLAIM_PROXY}"
+    fi
+  fi
+
+  # shellcheck disable=SC2086
+  run_as_root "${NETDATA_CLAIM_PATH}" -token="${NETDATA_CLAIM_TOKEN}" -rooms="${NETDATA_CLAIM_ROOMS}" -url="${NETDATA_CLAIM_URL}" ${NETDATA_CLAIM_EXTRA}
+  case $? in
+    0) progress "Successfully claimed node" ;;
+    1) warning "Unable to claim node due to invalid claiming options. If you are seeing this message, you’ve probably found a bug and should open a bug report at ${AGENT_BUG_REPORT_URL}" ;;
+    2) warning "Unable to claim node due to issues creating the claiming directory or preparing the local claiming key. Make sure you have a working openssl command and that ${INSTALL_PREFIX}/var/lib/netdata/cloud.d exists, then try again." ;;
+    3) warning "Unable to claim node due to missing dependencies. Usually this means that the Netdata Agent was built without support for Netdata Cloud. If you built the agent from source, please install all needed dependencies for Cloud support. If you used the regular installation script and see this error, please file a bug report at ${AGENT_BUG_REPORT_URL}." ;;
+    4) warning "Failed to claim node due to inability to connect to ${NETDATA_CLAIM_URL}. Usually this either means that the specified claiming URL is wrong, or that you are having networking problems." ;;
+    5) progress "Successfully claimed node, but was not able to notify the Netdata Agent. You will need to restart the Netdata service on this node before it will show up in the Cloud." ;;
+    8) warning "Failed to claim node due to an invalid agent ID. You can usually resolve this by removing ${INSTALL_PREFIX}/var/lib/netdata/registry/netdata.public.unique.id and restarting the agent. Then try to claim it again using the same options." ;;
+    9) warning "Failed to claim node due to an invalid node name. This probably means you tried to specify a custom name for this node (for example, using the --claim-hostname option), but the hostname itself was either empty or consisted solely of whitespace. You can resolve this by specifying a valid host name and trying again." ;;
+    10) warning "Failed to claim node due to an invalid room ID. This issue is most likely caused by a typo.  Please check if the room(s) you are trying to add appear on the list of rooms provided to the --claim-rooms option ('${NETDATA_CLAIM_ROOMS}'). Then verify if the rooms are visible in Netdata Cloud and try again." ;;
+    11) warning "Failed to claim node due to an issue with the generated RSA key pair. You can usually resolve this by removing all files in ${INSTALL_PREFIX}/var/lib/netdata/cloud.d and then trying again." ;;
+    12) warning "Failed to claim node due to an invalid or expired claiming token. Please check that the token specified with the --claim-token option ('${NETDATA_CLAIM_TOKEN}') matches what you see in the Cloud and try again." ;;
+    13) warning "Failed to claim node because the Cloud thinks it is already claimed. If this node was created by cloning a VM or as a container from a template, please remove the file ${INSTALL_PREFIX}/var/lib/netdata/registry/netdata.public.unique.id and restart the agent. Then try to claim it again with the same options. Otherwise, if you are certain this node has never been claimed before, you can use the --claim-id option to specify a new node ID to use for claiming, for example by using the uuidgen command like so: --claim-id \"\$(uuidgen)\"" ;;
+    14) warning "Failed to claim node because the node is already in the process of being claimed. You should not need to do anything to resolve this, the node should show up properly in the Cloud soon. If it does not, please report a bug at ${AGENT_BUG_REPORT_URL}." ;;
+    15|16|17) warning "Failed to claim node due to an internal server error in the Cloud. Please retry claiming this node later, and if you still see this message file a bug report at ${CLOUD_BUG_REPORT_URL}." ;;
+    18) warning "Unable to claim node because this Netdata installation does not have a unique ID yet. Make sure the agent is running and started up correctly, and then try again." ;;
+    *) warning "Failed to claim node for an unknown reason. This usually means either networking problems or a bug. Please retry claiming later, and if you still see this message file a bug report at ${AGENT_BUG_REPORT_URL}" ;;
+  esac
+}
+
 claim() {
   if [ "${DRY_RUN}" -eq 1 ]; then
     progress "Would attempt to claim agent to ${NETDATA_CLAIM_URL}"
@@ -1300,17 +1345,18 @@ claim() {
     NETDATA_CLAIM_PATH="${INSTALL_PREFIX}/netdata/usr/sbin/netdata-claim.sh"
   fi
 
+  method="script"
   err_msg=
   err_code=
   if [ -z "${NETDATA_CLAIM_PATH}" ]; then
-    err_msg="Unable to claim node: could not find usable claiming script. Reinstalling Netdata may resolve this."
-    err_code=F050B
+    method="config"
   elif [ ! -e "${NETDATA_CLAIM_PATH}" ]; then
-    err_msg="Unable to claim node: ${NETDATA_CLAIM_PATH} does not exist."
-    err_code=F0512
+    method="config"
   elif [ ! -f "${NETDATA_CLAIM_PATH}" ]; then
     err_msg="Unable to claim node: ${NETDATA_CLAIM_PATH} is not a file."
     err_code=F0513
+  elif grep -q '%%NEW_CLAIMING_METHOD%%' "${NETDATA_CLAIM_PATH}"; then
+    method="config"
   elif [ ! -x "${NETDATA_CLAIM_PATH}" ]; then
     err_msg="Unable to claim node: claiming script at ${NETDATA_CLAIM_PATH} is not executable. Reinstalling Netdata may resolve this."
     err_code=F0514
@@ -1326,34 +1372,16 @@ claim() {
   fi
 
   if ! is_netdata_running; then
-    NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -daemon-not-running"
+    NETDATA_CLAIM_NORELOAD=1
   fi
 
-  # shellcheck disable=SC2086
-  run_as_root "${NETDATA_CLAIM_PATH}" -token="${NETDATA_CLAIM_TOKEN}" -rooms="${NETDATA_CLAIM_ROOMS}" -url="${NETDATA_CLAIM_URL}" ${NETDATA_CLAIM_EXTRA}
-  case $? in
-    0)
-      progress "Successfully claimed node"
-      return 0
+  case ${method} in
+    script) run_claim_script ;;
+    config)
+      if ! write_claim_config; then
+        warning "Failed to write claiming configuration. This usually means you do not have permissions to access the configuration directory."
+      fi
       ;;
-    1) warning "Unable to claim node due to invalid claiming options. If you are seeing this message, you’ve probably found a bug and should open a bug report at ${AGENT_BUG_REPORT_URL}" ;;
-    2) warning "Unable to claim node due to issues creating the claiming directory or preparing the local claiming key. Make sure you have a working openssl command and that ${INSTALL_PREFIX}/var/lib/netdata/cloud.d exists, then try again." ;;
-    3) warning "Unable to claim node due to missing dependencies. Usually this means that the Netdata Agent was built without support for Netdata Cloud. If you built the agent from source, please install all needed dependencies for Cloud support. If you used the regular installation script and see this error, please file a bug report at ${AGENT_BUG_REPORT_URL}." ;;
-    4) warning "Failed to claim node due to inability to connect to ${NETDATA_CLAIM_URL}. Usually this either means that the specified claiming URL is wrong, or that you are having networking problems." ;;
-    5)
-      progress "Successfully claimed node, but was not able to notify the Netdata Agent. You will need to restart the Netdata service on this node before it will show up in the Cloud."
-      return 0
-      ;;
-    8) warning "Failed to claim node due to an invalid agent ID. You can usually resolve this by removing ${INSTALL_PREFIX}/var/lib/netdata/registry/netdata.public.unique.id and restarting the agent. Then try to claim it again using the same options." ;;
-    9) warning "Failed to claim node due to an invalid node name. This probably means you tried to specify a custom name for this node (for example, using the --claim-hostname option), but the hostname itself was either empty or consisted solely of whitespace. You can resolve this by specifying a valid host name and trying again." ;;
-    10) warning "Failed to claim node due to an invalid room ID. This issue is most likely caused by a typo.  Please check if the room(s) you are trying to add appear on the list of rooms provided to the --claim-rooms option ('${NETDATA_CLAIM_ROOMS}'). Then verify if the rooms are visible in Netdata Cloud and try again." ;;
-    11) warning "Failed to claim node due to an issue with the generated RSA key pair. You can usually resolve this by removing all files in ${INSTALL_PREFIX}/var/lib/netdata/cloud.d and then trying again." ;;
-    12) warning "Failed to claim node due to an invalid or expired claiming token. Please check that the token specified with the --claim-token option ('${NETDATA_CLAIM_TOKEN}') matches what you see in the Cloud and try again." ;;
-    13) warning "Failed to claim node because the Cloud thinks it is already claimed. If this node was created by cloning a VM or as a container from a template, please remove the file ${INSTALL_PREFIX}/var/lib/netdata/registry/netdata.public.unique.id and restart the agent. Then try to claim it again with the same options. Otherwise, if you are certain this node has never been claimed before, you can use the --claim-id option to specify a new node ID to use for claiming, for example by using the uuidgen command like so: --claim-id \"\$(uuidgen)\"" ;;
-    14) warning "Failed to claim node because the node is already in the process of being claimed. You should not need to do anything to resolve this, the node should show up properly in the Cloud soon. If it does not, please report a bug at ${AGENT_BUG_REPORT_URL}." ;;
-    15|16|17) warning "Failed to claim node due to an internal server error in the Cloud. Please retry claiming this node later, and if you still see this message file a bug report at ${CLOUD_BUG_REPORT_URL}." ;;
-    18) warning "Unable to claim node because this Netdata installation does not have a unique ID yet. Make sure the agent is running and started up correctly, and then try again." ;;
-    *) warning "Failed to claim node for an unknown reason. This usually means either networking problems or a bug. Please retry claiming later, and if you still see this message file a bug report at ${AGENT_BUG_REPORT_URL}" ;;
   esac
 
   if [ "${ACTION}" = "claim" ]; then
@@ -1938,12 +1966,6 @@ build_and_install() {
     opts="${opts} --stable-channel"
   fi
 
-  if [ "${NETDATA_REQUIRE_CLOUD}" -eq 1 ]; then
-    opts="${opts} --require-cloud"
-  elif [ "${NETDATA_DISABLE_CLOUD}" -eq 1 ]; then
-    opts="${opts} --disable-cloud"
-  fi
-
   # shellcheck disable=SC2086
   run_script ./netdata-installer.sh ${opts}
 
@@ -2392,12 +2414,10 @@ parse_args() {
         esac
         ;;
       "--disable-cloud")
-        NETDATA_DISABLE_CLOUD=1
-        NETDATA_REQUIRE_CLOUD=0
+        warning "Cloud cannot be disabled"
         ;;
       "--require-cloud")
-        NETDATA_DISABLE_CLOUD=0
-        NETDATA_REQUIRE_CLOUD=1
+        warning "Cloud is always required"
         ;;
       "--dont-start-it")
         NETDATA_NO_START=1
@@ -2447,26 +2467,21 @@ parse_args() {
       "--native-only") NETDATA_FORCE_METHOD="native" ;;
       "--static-only") NETDATA_FORCE_METHOD="static" ;;
       "--build-only") NETDATA_FORCE_METHOD="build" ;;
-      "--claim-token")
-        NETDATA_CLAIM_TOKEN="${2}"
-        shift 1
-        ;;
-      "--claim-rooms")
-        NETDATA_CLAIM_ROOMS="${2}"
-        shift 1
-        ;;
-      "--claim-url")
-        NETDATA_CLAIM_URL="${2}"
-        shift 1
-        ;;
       "--claim-"*)
         optname="$(echo "${1}" | cut -d '-' -f 4-)"
         case "${optname}" in
-          id|proxy|user|hostname)
+          token) NETDATA_CLAIM_TOKEN="${2}"; shift 1 ;;
+          rooms) NETDATA_CLAIM_ROOMS="${2}"; shift 1 ;;
+          url) NETDATA_CLAIM_URL="${2}"; shift 1 ;;
+          proxy) NETDATA_CLAIM_PROXY="${2}"; shift 1 ;;
+          noproxy) NETDATA_CLAIM_PROXY="none" ;;
+          insecure) NETDATA_CLAIM_INSECURE=yes ;;
+          noreload) NETDATA_CLAIM_NORELOAD=1 ;;
+          id|user|hostname)
             NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -${optname}=${2}"
             shift 1
             ;;
-          verbose|insecure|noproxy|noreload|daemon-not-running) NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -${optname}" ;;
+          verbose|daemon-not-running) NETDATA_CLAIM_EXTRA="${NETDATA_CLAIM_EXTRA} -${optname}" ;;
           *) warning "Ignoring unrecognized claiming option ${optname}" ;;
         esac
         ;;
