@@ -837,7 +837,7 @@ int do_sys_class_drm(int update_every, usec_t dt) {
     if(unlikely(!drm_dir)) {
         char filename[FILENAME_MAX + 1];
         snprintfz(filename, FILENAME_MAX, "%s%s", netdata_configured_host_prefix, "/sys/class/drm");
-        char *drm_dir_name = config_get(CONFIG_SECTION_PLUGIN_PROC_DRM, "directory to monitor", filename);
+        const char *drm_dir_name = config_get(CONFIG_SECTION_PLUGIN_PROC_DRM, "directory to monitor", filename);
         if(unlikely(NULL == (drm_dir = opendir(drm_dir_name)))){
             collector_error("Cannot read directory '%s'", drm_dir_name);
             return 1;
