@@ -920,8 +920,6 @@ static void xenstat_send_domain_metrics() {
 }
 
 int main(int argc, char **argv) {
-    clocks_init();
-
     // ------------------------------------------------------------------------
     // initialization of netdata plugin
 
@@ -1022,12 +1020,11 @@ int main(int argc, char **argv) {
     time_t started_t = now_monotonic_sec();
 
     size_t iteration;
-    usec_t step = netdata_update_every * USEC_PER_SEC;
 
     heartbeat_t hb;
-    heartbeat_init(&hb);
+    heartbeat_init(&hb, netdata_update_every * USEC_PER_SEC);
     for(iteration = 0; 1; iteration++) {
-        usec_t dt = heartbeat_next(&hb, step);
+        usec_t dt = heartbeat_next(&hb);
 
         if(unlikely(netdata_exit)) break;
 
