@@ -623,10 +623,10 @@ struct api_v2_contexts_request {
     char *contexts;
     char *q;
 
-    CONTEXTS_V2_OPTIONS options;
+    CONTEXTS_OPTIONS options;
 
     struct {
-        CONTEXTS_V2_ALERT_STATUS status;
+        CONTEXTS_ALERT_STATUS status;
         char *alert;
         char *transition;
         uint32_t last;
