@@ -11,6 +11,7 @@ typedef enum __attribute__((packed)) {
     RRD_FUNCTION_LOCAL  = (1 << 0),
     RRD_FUNCTION_GLOBAL = (1 << 1),
     RRD_FUNCTION_DYNCFG = (1 << 2),
+    RRD_FUNCTION_RESTRICTED = (1 << 3), // this function is restricted (hidden from user)
 
     // this is 8-bit
 } RRD_FUNCTION_OPTIONS;
@@ -23,6 +24,7 @@ struct rrd_host_function {
     STRING *tags;
     int timeout;                    // the default timeout of the function
     int priority;
+    uint32_t version;
 
     rrd_function_execute_cb_t execute_cb;
     void *execute_cb_data;
@@ -30,7 +32,6 @@ struct rrd_host_function {
     struct rrd_collector *collector;
 };
 
-size_t rrd_functions_sanitize(char *dst, const char *src, size_t dst_len);
 int rrd_functions_find_by_name(RRDHOST *host, BUFFER *wb, const char *name, size_t key_length, const DICTIONARY_ITEM **item);
 
 #endif //NETDATA_RRDFUNCTIONS_INTERNALS_H
