@@ -22,7 +22,7 @@ where
 `
 
 func (c *ClickHouse) collectSystemAsyncMetrics(mx map[string]int64) error {
-	req, _ := web.NewHTTPRequest(c.Request)
+	req, _ := web.NewHTTPRequest(c.RequestConfig)
 	req.URL.RawQuery = makeURLQuery(querySystemAsyncMetrics)
 
 	want := map[string]float64{
@@ -35,7 +35,7 @@ func (c *ClickHouse) collectSystemAsyncMetrics(mx map[string]int64) error {
 	var metric string
 	var n int
 
-	err := c.doOKDecodeCSV(req, func(column, value string, lineEnd bool) {
+	err := c.doHTTP(req, func(column, value string, lineEnd bool) {
 		switch column {
 		case "metric":
 			metric = value
