@@ -4,9 +4,9 @@ package cockroachdb
 
 import (
 	"errors"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
 
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/prometheus"
+	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
 )
 
 func (c *CockroachDB) validateConfig() error {
@@ -17,9 +17,9 @@ func (c *CockroachDB) validateConfig() error {
 }
 
 func (c *CockroachDB) initPrometheusClient() (prometheus.Prometheus, error) {
-	client, err := web.NewHTTPClient(c.Client)
+	client, err := web.NewHTTPClient(c.ClientConfig)
 	if err != nil {
 		return nil, err
 	}
-	return prometheus.New(client, c.Request), nil
+	return prometheus.New(client, c.RequestConfig), nil
 }
