@@ -5,7 +5,7 @@ package coredns
 import (
 	"errors"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/matcher"
+	"github.com/netdata/netdata/go/plugins/pkg/matcher"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/prometheus"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
 )
@@ -32,9 +32,9 @@ func (cd *CoreDNS) initPerZoneMatcher() (matcher.Matcher, error) {
 }
 
 func (cd *CoreDNS) initPrometheusClient() (prometheus.Prometheus, error) {
-	client, err := web.NewHTTPClient(cd.Client)
+	client, err := web.NewHTTPClient(cd.ClientConfig)
 	if err != nil {
 		return nil, err
 	}
-	return prometheus.New(client, cd.Request), nil
+	return prometheus.New(client, cd.RequestConfig), nil
 }
