@@ -5,7 +5,7 @@ package filecheck
 import (
 	"errors"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/matcher"
+	"github.com/netdata/netdata/go/plugins/pkg/matcher"
 )
 
 func (f *Filecheck) validateConfig() error {
