@@ -43,6 +43,7 @@ const (
 	prioPodMemLimitsUsed
 	prioPodCondition
 	prioPodPhase
+	prioPodStatusReason
 	prioPodAge
 	prioPodContainersCount
 	prioPodContainersState
@@ -106,6 +107,7 @@ var podChartsTmpl = module.Charts{
 	podMemLimitsUsedChartTmpl.Copy(),
 	podConditionChartTmpl.Copy(),
 	podPhaseChartTmpl.Copy(),
+	podStatusReasonChartTmpl.Copy(),
 	podAgeChartTmpl.Copy(),
 	podContainersCountChartTmpl.Copy(),
 	podContainersStateChartTmpl.Copy(),
@@ -247,15 +249,24 @@ var (
 		},
 	}
 	// condition
-	nodeConditionsChartTmpl = module.Chart{
-		IDSep:    true,
-		ID:       "node_%s.condition_status",
-		Title:    "Condition status",
-		Units:    "status",
-		Fam:      "node condition",
-		Ctx:      "k8s_state.node_condition",
-		Priority: prioNodeConditions,
-	}
+	nodeConditionsChartTmpl = func() module.Chart {
+		chart := module.Chart{
+			IDSep:    true,
+			ID:       "node_%s.condition_status",
+			Title:    "Condition status",
+			Units:    "status",
+			Fam:      "node condition",
+			Ctx:      "k8s_state.node_condition",
+			Priority: prioNodeConditions,
+		}
+		for _, v := range nodeConditionStatuses {
+			chart.Dims = append(chart.Dims, &module.Dim{
+				ID:   "node_%s_cond_" + v,
+				Name: v,
+			})
+		}
+		return chart
+	}()
 	nodeSchedulabilityChartTmpl = module.Chart{
 		IDSep:    true,
 		ID:       "node_%s.schedulability",
@@ -426,24 +437,6 @@ func (ks *KubeState) removeNodeCharts(ns *nodeState) {
 	}
 }
 
-func (ks *KubeState) addNodeConditionToCharts(ns *nodeState, cond string) {
-	id := fmt.Sprintf(nodeConditionsChartTmpl.ID, replaceDots(ns.id()))
-	c := ks.Charts().Get(id)
-	if c == nil {
-		ks.Warningf("chart '%s' does not exist", id)
-		return
-	}
-	dim := &module.Dim{
-		ID:   fmt.Sprintf("node_%s_cond_%s", ns.id(), strings.ToLower(cond)),
-		Name: cond,
-	}
-	if err := c.AddDim(dim); err != nil {
-		ks.Warning(err)
-		return
-	}
-	c.MarkNotCreated()
-}
-
 var (
 	podCPURequestsUsedChartTmpl = module.Chart{
 		IDSep:    true,
@@ -523,6 +516,24 @@ var (
 			{ID: "pod_%s_phase_pending", Name: "pending"},
 		},
 	}
+	podStatusReasonChartTmpl = func() module.Chart {
+		chart := module.Chart{
+			IDSep:    true,
+			ID:       "pod_%s.status_reason",
+			Title:    "Status reason",
+			Units:    "status",
+			Fam:      "pod status",
+			Ctx:      "k8s_state.pod_status_reason",
+			Priority: prioPodStatusReason,
+		}
+		for _, v := range podStatusReasons {
+			chart.Dims = append(chart.Dims, &module.Dim{
+				ID:   "pod_%s_status_reason_" + v,
+				Name: v,
+			})
+		}
+		return chart
+	}()
 	podAgeChartTmpl = module.Chart{
 		IDSep:    true,
 		ID:       "pod_%s.age",
@@ -681,24 +692,42 @@ var (
 			{ID: "pod_%s_container_%s_state_terminated", Name: "terminated"},
 		},
 	}
-	containersStateWaitingChartTmpl = module.Chart{
-		IDSep:    true,
-		ID:       "pod_%s_container_%s.state_waiting_reason",
-		Title:    "Container waiting state reason",
-		Units:    "state",
-		Fam:      "container waiting reason",
-		Ctx:      "k8s_state.pod_container_waiting_state_reason",
-		Priority: prioPodContainerWaitingStateReason,
-	}
-	containersStateTerminatedChartTmpl = module.Chart{
-		IDSep:    true,
-		ID:       "pod_%s_container_%s.state_terminated_reason",
-		Title:    "Container terminated state reason",
-		Units:    "state",
-		Fam:      "container terminated reason",
-		Ctx:      "k8s_state.pod_container_terminated_state_reason",
-		Priority: prioPodContainerTerminatedStateReason,
-	}
+	containersStateWaitingChartTmpl = func() module.Chart {
+		chart := module.Chart{
+			IDSep:    true,
+			ID:       "pod_%s_container_%s.state_waiting_reason",
+			Title:    "Container waiting state reason",
+			Units:    "state",
+			Fam:      "container waiting reason",
+			Ctx:      "k8s_state.pod_container_waiting_state_reason",
+			Priority: prioPodContainerWaitingStateReason,
+		}
+		for _, v := range containerWaitingStateReasons {
+			chart.Dims = append(chart.Dims, &module.Dim{
+				ID:   "pod_%s_container_%s_state_waiting_reason_" + v,
+				Name: v,
+			})
+		}
+		return chart
+	}()
+	containersStateTerminatedChartTmpl = func() module.Chart {
+		chart := module.Chart{
+			IDSep:    true,
+			ID:       "pod_%s_container_%s.state_terminated_reason",
+			Title:    "Container terminated state reason",
+			Units:    "state",
+			Fam:      "container terminated reason",
+			Ctx:      "k8s_state.pod_container_terminated_state_reason",
+			Priority: prioPodContainerTerminatedStateReason,
+		}
+		for _, v := range containerTerminatedStateReasons {
+			chart.Dims = append(chart.Dims, &module.Dim{
+				ID:   "pod_%s_container_%s_state_terminated_reason_" + v,
+				Name: v,
+			})
+		}
+		return chart
+	}()
 )
 
 func (ks *KubeState) newContainerCharts(ps *podState, cs *containerState) *module.Charts {
@@ -728,42 +757,6 @@ func (ks *KubeState) addContainerCharts(ps *podState, cs *containerState) {
 	}
 }
 
-func (ks *KubeState) addContainerWaitingStateReasonToChart(ps *podState, cs *containerState, reason string) {
-	id := fmt.Sprintf(containersStateWaitingChartTmpl.ID, replaceDots(ps.id()), cs.name)
-	c := ks.Charts().Get(id)
-	if c == nil {
-		ks.Warningf("chart '%s' does not exist", id)
-		return
-	}
-	dim := &module.Dim{
-		ID:   fmt.Sprintf("pod_%s_container_%s_state_waiting_reason_%s", ps.id(), cs.name, reason),
-		Name: reason,
-	}
-	if err := c.AddDim(dim); err != nil {
-		ks.Warning(err)
-		return
-	}
-	c.MarkNotCreated()
-}
-
-func (ks *KubeState) addContainerTerminatedStateReasonToChart(ps *podState, cs *containerState, reason string) {
-	id := fmt.Sprintf(containersStateTerminatedChartTmpl.ID, replaceDots(ps.id()), cs.name)
-	c := ks.Charts().Get(id)
-	if c == nil {
-		ks.Warningf("chart '%s' does not exist", id)
-		return
-	}
-	dim := &module.Dim{
-		ID:   fmt.Sprintf("pod_%s_container_%s_state_terminated_reason_%s", ps.id(), cs.name, reason),
-		Name: reason,
-	}
-	if err := c.AddDim(dim); err != nil {
-		ks.Warning(err)
-		return
-	}
-	c.MarkNotCreated()
-}
-
 var discoveryStatusChart = module.Chart{
 	ID:       "discovery_discoverers_state",
 	Title:    "Running discoverers state",
