@@ -3,8 +3,8 @@
 package openvpn
 
 import (
+	"github.com/netdata/netdata/go/plugins/pkg/matcher"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/modules/openvpn/client"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/matcher"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/socket"
 )
 
@@ -21,10 +21,8 @@ func (o *OpenVPN) initPerUserMatcher() (matcher.Matcher, error) {
 
 func (o *OpenVPN) initClient() *client.Client {
 	config := socket.Config{
-		Address:        o.Address,
-		ConnectTimeout: o.Timeout.Duration(),
-		ReadTimeout:    o.Timeout.Duration(),
-		WriteTimeout:   o.Timeout.Duration(),
+		Address: o.Address,
+		Timeout: o.Timeout.Duration(),
 	}
 	return &client.Client{Client: socket.New(config)}
 }
