@@ -4,7 +4,8 @@ package openvpn_status_log
 
 import (
 	"errors"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/matcher"
+
+	"github.com/netdata/netdata/go/plugins/pkg/matcher"
 )
 
 func (o *OpenVPNStatusLog) validateConfig() error {
