@@ -1,5 +1,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
+//go:build linux || freebsd || openbsd || netbsd || dragonfly
+
 package smartctl
 
 import (
@@ -9,7 +11,7 @@ import (
 	"time"
 
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
+	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/confopt"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -357,8 +359,8 @@ func TestSmartctl_Collect(t *testing.T) {
 			}
 			mock := test.prepareMock()
 			smart.exec = mock
-			smart.ScanEvery = web.Duration(time.Microsecond * 1)
-			smart.PollDevicesEvery = web.Duration(time.Microsecond * 1)
+			smart.ScanEvery = confopt.Duration(time.Microsecond * 1)
+			smart.PollDevicesEvery = confopt.Duration(time.Microsecond * 1)
 
 			var mx map[string]int64
 			for i := 0; i < 10; i++ {
@@ -366,25 +368,11 @@ func TestSmartctl_Collect(t *testing.T) {
 			}
 
 			assert.Equal(t, test.wantMetrics, mx)
-			assert.Len(t, *smart.Charts(), test.wantCharts)
-			testMetricsHasAllChartsDims(t, smart, mx)
-		})
-	}
-}
 
-func testMetricsHasAllChartsDims(t *testing.T, smart *Smartctl, mx map[string]int64) {
-	for _, chart := range *smart.Charts() {
-		if chart.Obsolete {
-			continue
-		}
-		for _, dim := range chart.Dims {
-			_, ok := mx[dim.ID]
-			assert.Truef(t, ok, "collected metrics has no data for dim '%s' chart '%s'", dim.ID, chart.ID)
-		}
-		for _, v := range chart.Vars {
-			_, ok := mx[v.ID]
-			assert.Truef(t, ok, "collected metrics has no data for var '%s' chart '%s'", v.ID, chart.ID)
-		}
+			assert.Len(t, *smart.Charts(), test.wantCharts, "wantCharts")
+
+			module.TestMetricsHasAllChartsDims(t, smart.Charts(), mx)
+		})
 	}
 }
 
