@@ -22,7 +22,7 @@ func (s *Supervisord) initSupervisorClient() (supervisorClient, error) {
 	if err != nil {
 		return nil, fmt.Errorf("parse 'url': %v (%s)", err, s.URL)
 	}
-	httpClient, err := web.NewHTTPClient(s.Client)
+	httpClient, err := web.NewHTTPClient(s.ClientConfig)
 	if err != nil {
 		return nil, fmt.Errorf("create HTTP client: %v", err)
 	}
