@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 //go:build linux
-// +build linux
 
 package systemdunits
 
@@ -9,7 +8,7 @@ import (
 	"errors"
 	"strings"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/matcher"
+	"github.com/netdata/netdata/go/plugins/pkg/matcher"
 )
 
 func (s *SystemdUnits) validateConfig() error {
