@@ -11,16 +11,16 @@ import (
 
 func (v *VerneMQ) validateConfig() error {
 	if v.URL == "" {
-		return errors.New("url is not set")
+		return errors.New("url is required but not set")
 	}
 	return nil
 }
 
 func (v *VerneMQ) initPrometheusClient() (prometheus.Prometheus, error) {
-	client, err := web.NewHTTPClient(v.Client)
+	client, err := web.NewHTTPClient(v.ClientConfig)
 	if err != nil {
 		return nil, err
 	}
 
-	return prometheus.New(client, v.Request), nil
+	return prometheus.New(client, v.RequestConfig), nil
 }
