@@ -49,7 +49,7 @@ func TestWindows_Init(t *testing.T) {
 	}{
 		"success if 'url' is set": {
 			config: Config{
-				HTTP: web.HTTP{Request: web.Request{URL: "http://127.0.0.1:9182/metrics"}}},
+				HTTPConfig: web.HTTPConfig{RequestConfig: web.RequestConfig{URL: "http://127.0.0.1:9182/metrics"}}},
 		},
 		"fails on default config": {
 			wantFail: true,
@@ -57,7 +57,7 @@ func TestWindows_Init(t *testing.T) {
 		},
 		"fails if 'url' is unset": {
 			wantFail: true,
-			config:   Config{HTTP: web.HTTP{Request: web.Request{URL: ""}}},
+			config:   Config{HTTPConfig: web.HTTPConfig{RequestConfig: web.RequestConfig{URL: ""}}},
 		},
 	}
 
@@ -817,7 +817,7 @@ func TestWindows_Collect(t *testing.T) {
 
 func testCharts(t *testing.T, win *Windows, mx map[string]int64) {
 	ensureChartsDimsCreated(t, win)
-	ensureCollectedHasAllChartsDimsVarsIDs(t, win, mx)
+	module.TestMetricsHasAllChartsDims(t, win.Charts(), mx)
 }
 
 func ensureChartsDimsCreated(t *testing.T, w *Windows) {
@@ -1047,19 +1047,6 @@ func ensureChartsDimsCreated(t *testing.T, w *Windows) {
 	}
 }
 
-func ensureCollectedHasAllChartsDimsVarsIDs(t *testing.T, w *Windows, mx map[string]int64) {
-	for _, chart := range *w.Charts() {
-		for _, dim := range chart.Dims {
-			_, ok := mx[dim.ID]
-			assert.Truef(t, ok, "collected metrics has no data for dim '%s' chart '%s'", dim.ID, chart.ID)
-		}
-		for _, v := range chart.Vars {
-			_, ok := mx[v.ID]
-			assert.Truef(t, ok, "collected metrics has no data for var '%s' chart '%s'", v.ID, chart.ID)
-		}
-	}
-}
-
 func prepareWindowsV0200() (win *Windows, cleanup func()) {
 	ts := httptest.NewServer(http.HandlerFunc(
 		func(w http.ResponseWriter, r *http.Request) {
