@@ -10,24 +10,37 @@ import (
 	"time"
 )
 
+// Processor function passed to the Socket.Command function.
+// It is passed by the caller to process a command's response line by line.
+type Processor func([]byte) bool
+
+// Client is the interface that wraps the basic socket client operations
+// and hides the implementation details from the users.
+// Implementations should return TCP, UDP or Unix ready sockets.
+type Client interface {
+	Connect() error
+	Disconnect() error
+	Command(command string, process Processor) error
+}
+
+func ConnectAndRead(cfg Config, process Processor) error {
+	sock := New(cfg)
+
+	if err := sock.Connect(); err != nil {
+		return err
+	}
+
+	defer func() { _ = sock.Disconnect() }()
+
+	return sock.read(process)
+}
+
 // New returns a new pointer to a socket client given the socket
 // type (IP, TCP, UDP, UNIX), a network address (IP/domain:port),
 // a timeout and a TLS config. It supports both IPv4 and IPv6 address
 // and reuses connection where possible.
-func New(config Config) *Socket {
-	return &Socket{
-		Config: config,
-		conn:   nil,
-	}
-}
-
-func ConnectAndRead(config Config, process Processor) error {
-	s := New(config)
-	if err := s.Connect(); err != nil {
-		return err
-	}
-	defer func() { _ = s.Disconnect() }()
-	return read(s.conn, process, s.ReadTimeout)
+func New(cfg Config) *Socket {
+	return &Socket{Config: cfg}
 }
 
 // Socket is the implementation of a socket client.
@@ -36,6 +49,14 @@ type Socket struct {
 	conn net.Conn
 }
 
+// Config holds the network ip v4 or v6 address, port,
+// Socket type(ip, tcp, udp, unix), timeout and TLS configuration for a Socket
+type Config struct {
+	Address string
+	Timeout time.Duration
+	TLSConf *tls.Config
+}
+
 // Connect connects to the Socket address on the named network.
 // If the address is a domain name it will also perform the DNS resolution.
 // Address like :80 will attempt to connect to the localhost.
@@ -46,10 +67,10 @@ func (s *Socket) Connect() error {
 	var err error
 
 	if s.TLSConf == nil {
-		conn, err = net.DialTimeout(network, address, s.ConnectTimeout)
+		conn, err = net.DialTimeout(network, address, s.timeout())
 	} else {
 		var d net.Dialer
-		d.Timeout = s.ConnectTimeout
+		d.Timeout = s.timeout()
 		conn, err = tls.DialWithDialer(&d, network, address, s.TLSConf)
 	}
 	if err != nil {
@@ -81,35 +102,52 @@ func (s *Socket) Command(command string, process Processor) error {
 	if s.conn == nil {
 		return errors.New("cannot send command on nil connection")
 	}
-	if err := write(command, s.conn, s.WriteTimeout); err != nil {
+
+	if err := s.write(command); err != nil {
 		return err
 	}
-	return read(s.conn, process, s.ReadTimeout)
+
+	return s.read(process)
 }
 
-func write(command string, writer net.Conn, timeout time.Duration) error {
-	if writer == nil {
+func (s *Socket) write(command string) error {
+	if s.conn == nil {
 		return errors.New("attempt to write on nil connection")
 	}
-	if err := writer.SetWriteDeadline(time.Now().Add(timeout)); err != nil {
+
+	if err := s.conn.SetWriteDeadline(time.Now().Add(s.timeout())); err != nil {
 		return err
 	}
-	_, err := writer.Write([]byte(command))
+
+	_, err := s.conn.Write([]byte(command))
+
 	return err
 }
 
-func read(reader net.Conn, process Processor, timeout time.Duration) error {
+func (s *Socket) read(process Processor) error {
 	if process == nil {
 		return errors.New("process func is nil")
 	}
-	if reader == nil {
+
+	if s.conn == nil {
 		return errors.New("attempt to read on nil connection")
 	}
-	if err := reader.SetReadDeadline(time.Now().Add(timeout)); err != nil {
+
+	if err := s.conn.SetReadDeadline(time.Now().Add(s.timeout())); err != nil {
 		return err
 	}
-	scanner := bufio.NewScanner(reader)
-	for scanner.Scan() && process(scanner.Bytes()) {
+
+	sc := bufio.NewScanner(s.conn)
+
+	for sc.Scan() && process(sc.Bytes()) {
 	}
-	return scanner.Err()
+
+	return sc.Err()
+}
+
+func (s *Socket) timeout() time.Duration {
+	if s.Timeout == 0 {
+		return time.Second
+	}
+	return s.Timeout
 }
