@@ -7,6 +7,8 @@
 #include <sys/syscall.h>
 #endif
 
+#include "random.h"
+#include "timestamps.h"
 #include "setproctitle.h"
 #include "close_range.h"
 #include "setresuid.h"
@@ -16,12 +18,21 @@
 #include "gettid.h"
 #include "get_pid_max.h"
 #include "get_system_cpus.h"
-#include "tinysleep.h"
+#include "sleep.h"
 #include "uuid_generate.h"
 #include "setenv.h"
 #include "os-freebsd-wrappers.h"
 #include "os-macos-wrappers.h"
 #include "os-windows-wrappers.h"
+#include "system-maps/cached-uid-username.h"
+#include "system-maps/cached-gid-groupname.h"
+#include "system-maps/cache-host-users-and-groups.h"
+#include "system-maps/cached-sid-username.h"
+#include "windows-perflib/perflib.h"
+
+// this includes windows.h to the whole of netdata
+// so various conflicts arise
+// #include "windows-wmi/windows-wmi.h"
 
 // =====================================================================================================================
 // common defs for Apple/FreeBSD/Linux
