@@ -1,7 +1,5 @@
 #include "../libnetdata.h"
 
-#ifdef ENABLE_HTTPS
-
 SSL_CTX *netdata_ssl_exporting_ctx =NULL;
 SSL_CTX *netdata_ssl_streaming_sender_ctx =NULL;
 SSL_CTX *netdata_ssl_web_server_ctx =NULL;
@@ -732,7 +730,7 @@ int security_test_certificate(SSL *ssl) {
  *
  * @return It returns 0 on success and -1 otherwise.
  */
-int ssl_security_location_for_context(SSL_CTX *ctx, char *file, char *path) {
+int ssl_security_location_for_context(SSL_CTX *ctx, const char *file, const char *path) {
     int load_custom = 1, load_default = 1;
     if (file || path) {
         if(!SSL_CTX_load_verify_locations(ctx, file, path)) {
@@ -751,4 +749,3 @@ int ssl_security_location_for_context(SSL_CTX *ctx, char *file, char *path) {
 
     return 0;
 }
-#endif
